pub struct AnimationContainer {
pub animation: Arc<dyn Animation>,
pub start: f32,
pub end: f32,
}Expand description
A wrapper around a animation to provide duration, delay, and other features.
Fields
animation: Arc<dyn Animation>The animation to be wrapped.
start: f32The start time of the animation in seconds.
end: f32The end time of the animation in seconds.
Implementations
Sourceimpl AnimationContainer
impl AnimationContainer
Sourcepub fn new(animation: Arc<dyn Animation>) -> Self
pub fn new(animation: Arc<dyn Animation>) -> Self
Creates a new AnimationContainer with the given animation.
Default duration is 1 second starting at 0 seconds.
Sourcepub fn duration(self, duration: f32) -> Self
pub fn duration(self, duration: f32) -> Self
Set the end time as to make the duration of the animation the given duration.
Sourcepub fn duration_keep_end(self, duration: f32) -> Self
pub fn duration_keep_end(self, duration: f32) -> Self
Set the start time as to make the duration of the animation the given duration.
Sourcepub fn after(self, other: &AnimationContainer) -> Self
pub fn after(self, other: &AnimationContainer) -> Self
Set the start time to the end time of the given animation. Preserving the duration of the animation.
Sourcepub fn start_with(self, other: &AnimationContainer) -> Self
pub fn start_with(self, other: &AnimationContainer) -> Self
Set the start time to the start time of the given animation.
Sourcepub fn end_with(self, other: &AnimationContainer) -> Self
pub fn end_with(self, other: &AnimationContainer) -> Self
Set the end time to the end time of the given animation.
Sourcepub fn synchronize(self, other: &AnimationContainer) -> Self
pub fn synchronize(self, other: &AnimationContainer) -> Self
Synchronize the start and end time with the given animation.